"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
const application_1 = require("@jupyterlab/application");
const coreutils_1 = require("@jupyterlab/coreutils");
const docmanager_1 = require("@jupyterlab/docmanager");
const filebrowser_1 = require("@jupyterlab/filebrowser");
const contents_1 = require("./contents");
const browser_1 = require("./browser");
require("../style/index.css");
/**
 * GitHub filebrowser plugin state namespace.
 */
const NAMESPACE = 'github-filebrowser';
/**
 * The ID for the plugin.
 */
const PLUGIN_ID = '@jupyterlab/github:drive';
/**
 * The JupyterLab plugin for the GitHub Filebrowser.
 */
const fileBrowserPlugin = {
    id: PLUGIN_ID,
    requires: [
        docmanager_1.IDocumentManager,
        filebrowser_1.IFileBrowserFactory,
        application_1.ILayoutRestorer,
        coreutils_1.ISettingRegistry
    ],
    activate: activateFileBrowser,
    autoStart: true
};
/**
 * Activate the file browser.
 */
function activateFileBrowser(app, manager, factory, restorer, settingRegistry) {
    const { commands } = app;
    // Add the GitHub backend to the contents manager.
    const drive = new contents_1.GitHubDrive(app.docRegistry);
    manager.services.contents.addDrive(drive);
    // Create the embedded filebrowser. GitHub repos likely
    // don't need as often of a refresh interval as normal ones,
    // and rate-limiting can be an issue, so we give a 5 minute
    // refresh interval.
    const browser = factory.createFileBrowser(NAMESPACE, {
        commands,
        driveName: drive.name,
        refreshInterval: 300000
    });
    const gitHubBrowser = new browser_1.GitHubFileBrowser(browser, drive);
    gitHubBrowser.title.iconClass = 'jp-GitHub-icon jp-SideBar-tabIcon';
    gitHubBrowser.title.caption = 'Browse GitHub';
    gitHubBrowser.id = 'github-file-browser';
    // Add the file browser widget to the application restorer.
    restorer.add(gitHubBrowser, NAMESPACE);
    app.shell.addToLeftArea(gitHubBrowser, { rank: 102 });
    const onSettingsUpdated = (settings) => {
        const baseUrl = settings.get('baseUrl').composite;
        gitHubBrowser.baseUrl = baseUrl || browser_1.DEFAULT_GITHUB_BASE_URL;
    };
    // Fetch the initial state of the settings.
    Promise.all([settingRegistry.load(PLUGIN_ID), app.restored])
        .then(([settings]) => {
        settings.changed.connect(onSettingsUpdated);
        onSettingsUpdated(settings);
        const defaultRepo = settings.get('defaultRepo').composite;
        if (defaultRepo) {
            browser.model.restored.then(() => {
                browser.model.cd(`/${defaultRepo}`);
            });
        }
    })
        .catch((reason) => {
        console.error(reason.message);
    });
    return;
}
exports.default = fileBrowserPlugin;
